==> plxDonnerAvis.2.0.0.zip: plxDonnerAvis/form.donneravis.php <==
<?php if(!defined('PLX_ROOT')) exit; ?>
<?php
/**
 * Plugin for Pluxml
 * @author	DPFPIC
 * Site : http://monblog.dpfpic.com/
 * Licence GNU_GPL
 **/

# récuperation d'une instance de plxShow
$plxShow = plxShow::getInstance();
$plxMotor = plxMotor::getInstance();
$plxShow->plxMotor->plxCapcha = new plxCapcha();
$plxPlugin = $plxShow->plxMotor->plxPlugins->getInstance('plxDonnerAvis');

$plxPlugin->donneravis->getPagedaFront();

$_SESSION['idart'] = '0000';
if (isset($_POST['idart'])) $_SESSION['idart'] = $_POST['idart'];
if (isset($_GET['idart'])) $_SESSION['idart'] = $_GET['idart'];
if (isset($_GET['title'])) $_SESSION['title'] = $plxPlugin->donneravis->my_simple_crypt($_GET['title'], 'd');
$bypage = intval($plxPlugin->getParam('byPage'));
$start = $bypage*($plxPlugin->donneravis->page-1);
$doavis = $plxPlugin->donneravis->getDonnerAvis($plxPlugin->getParam('tri_da'),'online',$start,$bypage,$_SESSION['idart']);
$nbDAPagination=$plxPlugin->donneravis->nbDonnerAvisByart('online',$_SESSION['idart']);

$direct = $plxPlugin->getParam('mod'); # 1 - modération : 0 - pas de modération
$error = false;
$success = false;
$comment = array();
$captcha = $plxPlugin->getParam('captcha')=='' ? '1' : $plxPlugin->getParam('captcha');
if(empty($_POST) AND (empty($_POST['submit']) AND !empty($_POST['btn_ok2']) AND $_POST['btn_ok2']!='add')) {
	unset($_SESSION['rate']);
}

# Gestion des erreurs
if(!empty($_POST) AND (!empty($_POST['submit']) AND !empty($_POST['btn_ok2']) AND $_POST['btn_ok2']=='add')) {
	# pour compatibilité avec le plugin plxMyCapchaImage
	if(strlen($_SESSION['capcha'])<=10)
		$_SESSION['capcha']=sha1($_SESSION['capcha']);
	$author = plxUtils::unSlash($_POST['author']);
	if (isset($_SESSION['rate'])) {$stars = plxUtils::unSlash($_SESSION['rate']);} else {$stars=0;}
	$avis = plxUtils::unSlash($_POST['avis']);
	$content=plxUtils::unSlash($_POST['content']);
	$idart=$_POST['idart'];
	
	if (isset($_POST['actmail'])) { $actmail = 'on'; } else { $actmail = 'off'; }
	if(empty($_SESSION['rate']))
		$error = $plxPlugin->getLang('L_DA_ERR_RATE');
	elseif(empty($avis))
		$error = $plxPlugin->getLang('L_DA_ERR_AVIS');	
	elseif(trim($content)=='')
			$error = $plxPlugin->getLang('L_DA_ERR_CONTENT');
	elseif(strlen($content) < 100)
			$error = $plxPlugin->getLang('L_DA_ERR_MAX');		
	elseif(trim($author)=='')
		$error = $plxPlugin->getLang('L_DA_ERR_AUTHOR');		
	elseif($captcha != 0 AND $_SESSION['capcha'] != sha1($_POST['rep']))
		$error = $plxPlugin->getLang('L_DA_ERR_ANTISPAM');
	if(!$error) {
		$comment['author'] = $author;
		$comment['ip'] = plxUtils::getIp();
		$comment['stars'] = $stars;
		$comment['actmail'] = $actmail;
		$comment['avis'] = $avis;
		$comment['content'] = $content;
		# Génération du nouveau nom du fichier
		$nbnote = $plxPlugin->donneravis->nextIdDA();
		$time = time();
		$date =strftime("%Y%m%d%H%M",$time);
		$comment['nbnote'] = $nbnote;
		if ($direct == 1) { $first = '_'; } else { $first = ''; }
		$comment['id'] = $first.$date.'_a'.$idart.'_'.$nbnote;
		
		$dte = plxDate::date2Array($date);
		
		# préparation du contenu du mail
		$corps  = $plxPlugin->getLang('L_DA_FORM_CORPS_1')." ".$dte['day']."-".$dte['month']."-".$dte['year']." ".$dte['time']."<br />"."\t\n";
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_2')." : ".$author."<br />"."\t\n";
		$corps .= "---------------------------<br />"."\t\n";		
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_4')."<br />"."\t\n";
		$corps .= $content."<br />"."\t\n";
		$corps .= "---------------------------<br />"."\t\n";
		if ($direct == 1) {
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_5')." :<br />"."\t\n";
		$corps .= "<a href='".plxUtils::getRacine()."core/admin/plugin.php?p=plxDonnerAvis&sel=offline&page=1' title='Rubrique 1'>".$plxPlugin->getLang('L_DA_FORM_CORPS_6')."</a><br />"."\t\n";
		} else {
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_7')." :<br />"."\t\n";
		$corps .= "<a href='".plxUtils::getRacine()."core/admin/plugin.php?p=plxDonnerAvis' title='Rubrique 1'>".$plxPlugin->getLang('L_DA_FORM_CORPS_6')."</a><br />"."\t\n";		
		}
		$corps .= " "."\t\n";
		
		$email = $plxPlugin->getParam('email');
		$email_cc = $plxPlugin->getParam('email_cc');
		
		if ($plxPlugin->donneravis->addDonnerAvis($comment)) # Ajout du nouveau message
		if ($plxPlugin->getParam('supervision') == 1) {
		if(plxUtils::sendMail($plxPlugin->getParam('site'),$plxPlugin->getParam('email_from'),$email,$plxPlugin->getParam('subject'),$corps,'html',$email_cc)) {
			$success = $plxPlugin->getParam('thankyou');
		} else {
			$error = $plxPlugin->getLang('L_DA_ERR_SENDMAIL');
		}	
		} else {
			$success = $plxPlugin->getParam('thankyou');
		}
	} else {
		$_POST['btn_ok3'] = 'new';
	}
} else {
	$author = '';
	$stars = '';
	$actmail = 'off';
	$content = '';
	$avis = '';
}
if($error): ?>
	<p class="avis_error"><?php echo $error ?></p>
<?php endif;
$nbDA = 1;
if (!$success) {	
	$nbDA = $plxPlugin->donneravis->nbDonnerAvisByart('online',$_SESSION['idart']);
}
if (!isset($_GET['idnew'])) {$_GET['idnew'] = false;}
if (isset($_SESSION['rate'])) {$val = $_SESSION['rate'];} else {$val=0;}
if (!empty($_POST['submit']) AND $_POST['btn_ok3']=='new' OR $nbDA == 0 OR $_GET['idnew'] == true) {
?>
<div id="form_avis">
	<?php if ($_SESSION['idart'] != '0000') { ?>
	<p><?php echo $plxPlugin->getLang('L_DA_MSG_WELCOME').' : '.$_SESSION['title']; ?>.</p>
	<?php } ?>
	<span class="remark"><?php $plxPlugin->lang('L_DA_MSG_RATING') ?>.</span>&nbsp;<span class="remarkred2">*</span>
	<form action="<?php echo $plxMotor->urlRewrite('index.php?donneravis'); ?>" method="post">
		<input id="id_add2" name="btn_ok2" type="hidden" value="add" />
		<input id="id_add3" name="btn_ok3" type="hidden" value="" />
		<input id="id_idart" name="idart" type="hidden" value="<?php echo $_SESSION['idart']; ?>" />
            <div class="rating">
                <div class="star"></div>
				<div style="clear: both"></div>
            </div>
        <!-- JS to add -->
        <script type="text/javascript">
            $(".star").stars({ 
				stars: <?php echo $plxPlugin->getParam('nbStars'); ?>,
				<?php echo 'text: ["'.$plxPlugin->getParam('labelstar_1').'", "'.$plxPlugin->getParam('labelstar_2').'", "'.$plxPlugin->getParam('labelstar_3').'", "'.$plxPlugin->getParam('labelstar_4').'", "'.$plxPlugin->getParam('labelstar_5').'", "'.$plxPlugin->getParam('labelstar_6').
				'", "'.$plxPlugin->getParam('labelstar_7').'", "'.$plxPlugin->getParam('labelstar_8').'", "'.$plxPlugin->getParam('labelstar_9').'", "'.$plxPlugin->getParam('labelstar_10').'"],'; ?>
				/*color: '#<?php echo $plxPlugin->getParam('colorStar'); ?>',*/
				isDisabled: false,
				value: <?php echo $val; ?>,
                click: function(index) {
					$.post('<?php echo PLX_PLUGINS; ?>plxDonnerAvis/rating.php?tk=ok', {rate : index, action : 'rating'});	
                }
            });
         </script>
		
		<p>
			<label for="avis"><?php $plxPlugin->lang('L_DA_FORM_TITLE_AVIS') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_FORM_TITLE_REMARK') ?>.</span></label>
			<input id="avis" name="avis" type="text" size="30" placeholder="<?php $_SESSION['idart'] != '0000' ? $plxPlugin->lang('L_DA_PLACEHOLDER_TITLE_AVIS') : $plxPlugin->lang('L_DA_PLACEHOLDER_TITLE_SITE'); ?>" value="<?php echo plxUtils::strCheck($avis) ?>" />
		</p>
		<p>&nbsp;</p>
			<label for="message"><?php $plxPlugin->lang('L_DA_FORM_CONTENT') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_MAX_CARACT') ?>.</span></label>
			<textarea id="message" name="content" cols="30" rows="6" placeholder="<?php $_SESSION['idart'] != '0000' ? $plxPlugin->lang('L_DA_PLACEHOLDER_CONTENT') : $plxPlugin->lang('L_DA_PLACEHOLDER_CONTENT_SITE'); ?>"><?php echo plxUtils::strCheck($content) ?></textarea>
			<div class="compter"><span id="counter" class="count"></span></div>
	
 <script type="text/javascript">
   $(document).ready(function() {
      count($("#message"),$("#counter"));
      $("#message").keyup(function() {
         count($("#message"),$("#counter"));
      });
   });

function count(src,dest){
  var txtVal = src.val();
  var chars = txtVal.length;
  dest.html(chars +'/100 <?php echo $plxPlugin->lang('L_DA_CARACT') ?>');
}

</script>
		<p>		
			<label for="author"><?php $plxPlugin->lang('L_DA_FORM_PSEUDO') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_FORM_PSEUDO_REMARK') ?>.</span></label>
			<input id="author" name="author" type="text" size="30" value="<?php echo plxUtils::strCheck($author) ?>" maxlength="30" placeholder="<?php $plxPlugin->lang('L_DA_PLACEHOLDER_PSEUDO') ?>" />
		</p>		
<?php if($captcha): ?>
		<p>
		<label for="id_rep"><strong><?php $plxPlugin->lang('L_DA_FORM_ANTISPAM') ?></strong>&nbsp;<span class="remarkred2">*</span>&nbsp;</label>
		<?php $plxShow->capchaQ(); ?>
		<input id="id_rep" name="rep" type="text" size="2" maxlength="1" style="width: auto; display: inline;" autocomplete="off" />
		</p>
		<?php endif; ?>
		<p>
			<input type="submit" name="submit" value="<?php $plxPlugin->lang('L_DA_FORM_BTN_SEND') ?>" />
		</p>
	</form>
	<span class="remarkred"><?php $plxPlugin->lang('L_DA_REMARK') ?></span>
</div>
<?php } else { ?>
<?php if($success): ?>
		<p class="avis_success"><?php echo plxUtils::strCheck($success) ?>
	<?php if($direct == 1): ?>
		&nbsp;<?php $plxPlugin->lang('L_DA_FORM_MOD') ?>.
		<?php endif; ?>
	</p>
	<?php if ($_SESSION['idart'] != '0000') { ?>
		<?php $plxPlugin->donneravis->RedirDA('index.php?'.$_SESSION['QUERY_STRING']); ?>
	<?php } else {?>
		<?php $plxPlugin->donneravis->RedirDA('index.php?donneravis'); ?>
	<?php } ?>
	<?php endif; ?>	
<?php if ($_SESSION['idart'] == '0000') { ?>	
<p><?php $plxPlugin->lang('L_DA_MESSAGE') ?>.</p>
<?php } else { ?>
<p>&nbsp;</p>
<?php } ?>
<form class="newda" action="#form" method="post">
	<input id="id_add" name="btn_ok2" type="hidden" value="" />
	<input id="id_new" name="btn_ok3" type="hidden" value="new" />
	<input id="id_idart" name="idart" type="hidden" value="<?php echo $_SESSION['idart']; ?>" />
    <input type="submit" name="submit" value="<?php echo $plxPlugin->getParam('persButton') ?>" />
</form>
<?php if ($_SESSION['idart'] != '0000') { ?>
	<p><?php $plxPlugin->lang('L_DA_AVIS_ART') ?> : <?php echo $_SESSION['title']; ?></p>
<?php } else { 
		$total = 0;
		$nbDA = $plxPlugin->donneravis->nbDonnerAvisByart('online','0000');
		if (!empty($plxPlugin->donneravis->plxRecord_da)) {
			while($plxPlugin->donneravis->plxRecord_da->loop()) {
				$total = $total + $plxPlugin->donneravis->plxRecord_da->f('stars');
			}
		} else {
			$total = 0;
		}
		if ($total != 0) {
			$average = round($total / $nbDA,1);
		} else {
			$average = 0;
		}
	?>
	<p><?php echo $average; ?>/<?php echo $plxPlugin->getParam('nbStars'); ?>&nbsp;(<?php echo $nbDA; ?> <?php $plxPlugin->lang('L_DA_AVIS'); ?>)</p>
<?php } ?>
<?php if($plxPlugin->donneravis->plxRecord_da): ?>
	<div id="donneravis">
		<?php while($plxPlugin->donneravis->plxRecord_da->loop()): # On boucle sur les messages ?>
	<div class="review">
		<div class="content">
			<div class="title">
				<h4 class="color4">"<?php echo $plxPlugin->donneravis->plxRecord_da->f('avis'); ?>"</h4>
			</div>
			<div class="rating-review">
			<?php $plxPlugin->donneravis->rating($_SESSION['idart'], $plxPlugin->donneravis->plxRecord_da->f('stars'), $plxPlugin->getParam('nbStars'), $plxPlugin->getParam('colorStar')); ?>
			</div>
			<div class="description"><?php $plxPlugin->donneravis->daContent(); ?></div>
            <div class="published"><?php $plxPlugin->lang('L_DA_FORM_PUBLISHED') ?>&nbsp;<?php $plxPlugin->donneravis->daDate('#num_day-#num_month-#num_year(4) #hour:#minute'); ?>&nbsp;<?php $plxPlugin->lang('L_DA_FORM_BY') ?>&nbsp;<?php echo $plxPlugin->donneravis->plxRecord_da->f('author'); ?></div>
		</div>
</div> 

		<?php endwhile; # Fin de la boucle sur les messages ?>
	</div>
	<?php else: ?>
		<p>
			<?php $plxPlugin->lang('L_DA_FORM_NO_POST') ?>.
		</p>
	<?php endif; ?>	
	
<?php if ($nbDAPagination > $bypage) { 	?>
<span>&nbsp;</span>
<nav class="pagination text-center">
<?php
# Affichage de la pagination
	if($doavis) { # Si on a des messages (hors page)
		$plxPlugin->donneravis->Pagination($nbDAPagination,$bypage);
}
?>
</nav>	
<?php } ?>
<?php } ?>

==> plxDonnerAvis.2.0.1.zip: plxDonnerAvis/form.donneravis.php <==
<?php if(!defined('PLX_ROOT')) exit; ?>
<?php
/**
 * Plugin for Pluxml
 * @author	DPFPIC
 * Site : http://monblog.dpfpic.com/
 * Licence GNU_GPL
 **/

# récuperation d'une instance de plxShow
$plxShow = plxShow::getInstance();
$plxMotor = plxMotor::getInstance();
$plxShow->plxMotor->plxCapcha = new plxCapcha();
$plxPlugin = $plxShow->plxMotor->plxPlugins->getInstance('plxDonnerAvis');

$plxPlugin->donneravis->getPagedaFront();

$_SESSION['idart'] = '0000';
if (isset($_POST['idart'])) $_SESSION['idart'] = $_POST['idart'];
if (isset($_GET['idart'])) $_SESSION['idart'] = $_GET['idart'];
if (isset($_GET['title'])) $_SESSION['title'] = $plxPlugin->donneravis->my_simple_crypt($_GET['title'], 'd');
$bypage = intval($plxPlugin->getParam('byPage'));
$start = $bypage*($plxPlugin->donneravis->page-1);
$doavis = $plxPlugin->donneravis->getDonnerAvis($plxPlugin->getParam('tri_da'),'online',$start,$bypage,$_SESSION['idart']);
$nbDAPagination=$plxPlugin->donneravis->nbDonnerAvisByart('online',$_SESSION['idart']);

$direct = $plxPlugin->getParam('mod'); # 1 - modération : 0 - pas de modération
$error = false;
$success = false;
$comment = array();
$captcha = $plxPlugin->getParam('captcha')=='' ? '1' : $plxPlugin->getParam('captcha');
if(empty($_POST) AND (empty($_POST['submit']) AND isset($_POST['btn_ok2']) AND !empty($_POST['btn_ok2']) AND $_POST['btn_ok2']!='add')) {
	unset($_SESSION['rate']);
}

# Gestion des erreurs
if(!empty($_POST) AND (!empty($_POST['submit']) AND !empty($_POST['btn_ok2']) AND $_POST['btn_ok2']=='add')) {
	# pour compatibilité avec le plugin plxMyCapchaImage
	if(isset($_SESSION['capcha']) AND strlen($_SESSION['capcha'])<=10)
		$_SESSION['capcha']=sha1($_SESSION['capcha']);
	$author = plxUtils::unSlash($_POST['author']);
	if (isset($_SESSION['rate'])) {$stars = plxUtils::unSlash($_SESSION['rate']);} else {$stars=0;}
	$avis = plxUtils::unSlash($_POST['avis']);
	$content=plxUtils::unSlash($_POST['content']);
	$idart=$_POST['idart'];
	
	if (isset($_POST['actmail'])) { $actmail = 'on'; } else { $actmail = 'off'; }
	if(empty($_SESSION['rate']))
		$error = $plxPlugin->getLang('L_DA_ERR_RATE');
	elseif(empty($avis))
		$error = $plxPlugin->getLang('L_DA_ERR_AVIS');	
	elseif(trim($content)=='')
			$error = $plxPlugin->getLang('L_DA_ERR_CONTENT');
	elseif(strlen($content) < 100)
			$error = $plxPlugin->getLang('L_DA_ERR_MAX');		
	elseif(trim($author)=='')
		$error = $plxPlugin->getLang('L_DA_ERR_AUTHOR');		
	elseif($captcha != 0 AND $_SESSION['capcha'] != sha1($_POST['rep']))
		$error = $plxPlugin->getLang('L_DA_ERR_ANTISPAM');
	if(!$error) {
		$comment['author'] = $author;
		$comment['ip'] = plxUtils::getIp();
		$comment['stars'] = $stars;
		$comment['actmail'] = $actmail;
		$comment['avis'] = $avis;
		$comment['content'] = $content;
		# Génération du nouveau nom du fichier
		$nbnote = $plxPlugin->donneravis->nextIdDA();
		$time = time();
		$date =date("YmdHi",$time);
		$comment['nbnote'] = $nbnote;
		if ($direct == 1) { $first = '_'; } else { $first = ''; }
		$comment['id'] = $first.$date.'_a'.$idart.'_'.$nbnote;
		
		$dte = plxDate::date2Array($date);
		
		# préparation du contenu du mail
		$corps  = $plxPlugin->getLang('L_DA_FORM_CORPS_1')." ".$dte['day']."-".$dte['month']."-".$dte['year']." ".$dte['time']."<br />"."\t\n";
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_2')." : ".$author."<br />"."\t\n";
		$corps .= "---------------------------<br />"."\t\n";		
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_4')."<br />"."\t\n";
		$corps .= $content."<br />"."\t\n";
		$corps .= "---------------------------<br />"."\t\n";
		if ($direct == 1) {
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_5')." :<br />"."\t\n";
		$corps .= "<a href='".plxUtils::getRacine()."core/admin/plugin.php?p=plxDonnerAvis&sel=offline&page=1' title='Rubrique 1'>".$plxPlugin->getLang('L_DA_FORM_CORPS_6')."</a><br />"."\t\n";
		} else {
		$corps .= $plxPlugin->getLang('L_DA_FORM_CORPS_7')." :<br />"."\t\n";
		$corps .= "<a href='".plxUtils::getRacine()."core/admin/plugin.php?p=plxDonnerAvis' title='Rubrique 1'>".$plxPlugin->getLang('L_DA_FORM_CORPS_6')."</a><br />"."\t\n";		
		}
		$corps .= " "."\t\n";
		
		$email = $plxPlugin->getParam('email');
		$email_cc = $plxPlugin->getParam('email_cc');
		
		if ($plxPlugin->donneravis->addDonnerAvis($comment)) # Ajout du nouveau message
		if ($plxPlugin->getParam('supervision') == 1) {
		if(plxUtils::sendMail($plxPlugin->getParam('site'),$plxPlugin->getParam('email_from'),$email,$plxPlugin->getParam('subject'),$corps,'html',$email_cc)) {
			$success = $plxPlugin->getParam('thankyou');
		} else {
			$error = $plxPlugin->getLang('L_DA_ERR_SENDMAIL');
		}	
		} else {
			$success = $plxPlugin->getParam('thankyou');
		}
	} else {
		$_POST['btn_ok3'] = 'new';
	}
} else {
	$author = '';
	$stars = '';
	$actmail = 'off';
	$content = '';
	$avis = '';
}
if($error): ?>
	<p class="avis_error"><?php echo $error ?></p>
<?php endif;
$nbDA = 1;
if (!$success) {	
	$nbDA = $plxPlugin->donneravis->nbDonnerAvisByart('online',$_SESSION['idart']);
}
if (!isset($_GET['idnew'])) {$_GET['idnew'] = false;}
if (isset($_SESSION['rate'])) {$val = $_SESSION['rate'];} else {$val=0;}
if (!empty($_POST['submit']) AND $_POST['btn_ok3']=='new' OR $nbDA == 0 OR $_GET['idnew'] == true) {
?>
<div id="form_avis">
	<?php if ($_SESSION['idart'] != '0000') { ?>
	<p><?php echo $plxPlugin->getLang('L_DA_MSG_WELCOME').' : '.$_SESSION['title']; ?>.</p>
	<?php } ?>
	<span class="remark"><?php $plxPlugin->lang('L_DA_MSG_RATING') ?>.</span>&nbsp;<span class="remarkred2">*</span>
	<form action="<?php echo $plxMotor->urlRewrite('index.php?donneravis'); ?>" method="post">
		<input id="id_add2" name="btn_ok2" type="hidden" value="add" />
		<input id="id_add3" name="btn_ok3" type="hidden" value="" />
		<input id="id_idart" name="idart" type="hidden" value="<?php echo $_SESSION['idart']; ?>" />
            <div class="rating">
                <div class="star"></div>
				<div style="clear: both"></div>
            </div>
        <!-- JS to add -->
        <script type="text/javascript">
            $(".star").stars({ 
				stars: <?php echo $plxPlugin->getParam('nbStars'); ?>,
				<?php echo 'text: ["'.$plxPlugin->getParam('labelstar_1').'", "'.$plxPlugin->getParam('labelstar_2').'", "'.$plxPlugin->getParam('labelstar_3').'", "'.$plxPlugin->getParam('labelstar_4').'", "'.$plxPlugin->getParam('labelstar_5').'", "'.$plxPlugin->getParam('labelstar_6').
				'", "'.$plxPlugin->getParam('labelstar_7').'", "'.$plxPlugin->getParam('labelstar_8').'", "'.$plxPlugin->getParam('labelstar_9').'", "'.$plxPlugin->getParam('labelstar_10').'"],'; ?>
				/*color: '#<?php echo $plxPlugin->getParam('colorStar'); ?>',*/
				isDisabled: false,
				value: <?php echo $val; ?>,
                click: function(index) {
					$.post('<?php echo PLX_PLUGINS; ?>plxDonnerAvis/rating.php?tk=ok', {rate : index, action : 'rating'});	
                }
            });
         </script>
		
		<p>
			<label for="avis"><?php $plxPlugin->lang('L_DA_FORM_TITLE_AVIS') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_FORM_TITLE_REMARK') ?>.</span></label>
			<input id="avis" name="avis" type="text" size="30" placeholder="<?php $_SESSION['idart'] != '0000' ? $plxPlugin->lang('L_DA_PLACEHOLDER_TITLE_AVIS') : $plxPlugin->lang('L_DA_PLACEHOLDER_TITLE_SITE'); ?>" value="<?php echo plxUtils::strCheck($avis) ?>" />
		</p>
		<p>&nbsp;</p>
			<label for="message"><?php $plxPlugin->lang('L_DA_FORM_CONTENT') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_MAX_CARACT') ?>.</span></label>
			<textarea id="message" name="content" cols="30" rows="6" placeholder="<?php $_SESSION['idart'] != '0000' ? $plxPlugin->lang('L_DA_PLACEHOLDER_CONTENT') : $plxPlugin->lang('L_DA_PLACEHOLDER_CONTENT_SITE'); ?>"><?php echo plxUtils::strCheck($content) ?></textarea>
			<div class="compter"><span id="counter" class="count"></span></div>
	
 <script type="text/javascript">
   $(document).ready(function() {
      count($("#message"),$("#counter"));
      $("#message").keyup(function() {
         count($("#message"),$("#counter"));
      });
   });

function count(src,dest){
  var txtVal = src.val();
  var chars = txtVal.length;
  dest.html(chars +'/100 <?php echo $plxPlugin->lang('L_DA_CARACT') ?>');
}

</script>
		<p>		
			<label for="author"><?php $plxPlugin->lang('L_DA_FORM_PSEUDO') ?>&nbsp;<span class="remarkred2">*</span>&nbsp;:&nbsp;<span class="remark"><?php $plxPlugin->lang('L_DA_FORM_PSEUDO_REMARK') ?>.</span></label>
			<input id="author" name="author" type="text" size="30" value="<?php echo plxUtils::strCheck($author) ?>" maxlength="30" placeholder="<?php $plxPlugin->lang('L_DA_PLACEHOLDER_PSEUDO') ?>" />
		</p>		
<?php if($captcha): ?>
		<p>
		<label for="id_rep"><strong><?php $plxPlugin->lang('L_DA_FORM_ANTISPAM') ?></strong>&nbsp;<span class="remarkred2">*</span>&nbsp;</label>
		<?php $plxShow->capchaQ(); ?>
		<input id="id_rep" name="rep" type="text" size="2" maxlength="1" style="width: auto; display: inline;" autocomplete="off" />
		</p>
		<?php endif; ?>
		<p>
			<input type="submit" name="submit" value="<?php $plxPlugin->lang('L_DA_FORM_BTN_SEND') ?>" />
		</p>
	</form>
	<span class="remarkred"><?php $plxPlugin->lang('L_DA_REMARK') ?></span>
</div>
<?php } else { ?>
<?php if($success): ?>
		<p class="avis_success"><?php echo plxUtils::strCheck($success) ?>
	<?php if($direct == 1): ?>
		&nbsp;<?php $plxPlugin->lang('L_DA_FORM_MOD') ?>.
		<?php endif; ?>
	</p>
	<?php if ($_SESSION['idart'] != '0000') { ?>
		<?php $plxPlugin->donneravis->RedirDA('index.php?'.$_SESSION['QUERY_STRING']); ?>
	<?php } else {?>
		<?php $plxPlugin->donneravis->RedirDA('index.php?donneravis'); ?>
	<?php } ?>
	<?php endif; ?>	
<?php if ($_SESSION['idart'] == '0000') { ?>	
<p><?php $plxPlugin->lang('L_DA_MESSAGE') ?>.</p>
<?php } else { ?>
<p>&nbsp;</p>
<?php } ?>
<form class="newda" action="#form" method="post">
	<input id="id_add" name="btn_ok2" type="hidden" value="" />
	<input id="id_new" name="btn_ok3" type="hidden" value="new" />
	<input id="id_idart" name="idart" type="hidden" value="<?php echo $_SESSION['idart']; ?>" />
    <input type="submit" name="submit" value="<?php echo $plxPlugin->getParam('persButton') ?>" />
</form>
<?php if ($_SESSION['idart'] != '0000') { ?>
	<p><?php $plxPlugin->lang('L_DA_AVIS_ART') ?> : <?php echo $_SESSION['title']; ?></p>
<?php } else { 
		$total = 0;
		$nbDA = $plxPlugin->donneravis->nbDonnerAvisByart('online','0000');
		if (!empty($plxPlugin->donneravis->plxRecord_da)) {
			while($plxPlugin->donneravis->plxRecord_da->loop()) {
				$total = $total + $plxPlugin->donneravis->plxRecord_da->f('stars');
			}
		} else {
			$total = 0;
		}
		if ($total != 0) {
			$average = round($total / $nbDA,1);
		} else {
			$average = 0;
		}
	?>
	<p><?php echo $average; ?>/<?php echo $plxPlugin->getParam('nbStars'); ?>&nbsp;(<?php echo $nbDA; ?> <?php $plxPlugin->lang('L_DA_AVIS'); ?>)</p>
<?php } ?>
<?php if($plxPlugin->donneravis->plxRecord_da): ?>
	<div id="donneravis">
		<?php while($plxPlugin->donneravis->plxRecord_da->loop()): # On boucle sur les messages ?>
	<div class="review">
		<div class="content">
			<div class="title">
				<h4 class="color4">"<?php echo $plxPlugin->donneravis->plxRecord_da->f('avis'); ?>"</h4>
			</div>
			<div class="rating-review">
			<?php $plxPlugin->donneravis->rating($_SESSION['idart'], $plxPlugin->donneravis->plxRecord_da->f('stars'), $plxPlugin->getParam('nbStars'), $plxPlugin->getParam('colorStar')); ?>
			</div>
			<div class="description"><?php $plxPlugin->donneravis->daContent(); ?></div>
            <div class="published"><?php $plxPlugin->lang('L_DA_FORM_PUBLISHED') ?>&nbsp;<?php $plxPlugin->donneravis->daDate('#num_day-#num_month-#num_year(4) #hour:#minute'); ?>&nbsp;<?php $plxPlugin->lang('L_DA_FORM_BY') ?>&nbsp;<?php echo $plxPlugin->donneravis->plxRecord_da->f('author'); ?></div>
		</div>
</div> 

		<?php endwhile; # Fin de la boucle sur les messages ?>
	</div>
	<?php else: ?>
		<p>
			<?php $plxPlugin->lang('L_DA_FORM_NO_POST') ?>.
		</p>
	<?php endif; ?>	
	
<?php if ($nbDAPagination > $bypage) { 	?>
<span>&nbsp;</span>
<nav class="pagination text-center">
<?php
# Affichage de la pagination
	if($doavis) { # Si on a des messages (hors page)
		$plxPlugin->donneravis->Pagination($nbDAPagination,$bypage);
}
?>
</nav>	
<?php } ?>
<?php } ?>
